#!/bin/bash
#
# Copyright (C) 2004-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of le-edubar
#
# le-edubar is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.
width_old=0
height_old=0
dir="/usr/share/le-edubar/themes/Default-Single"
lock="${HOME}/.le-edubar_position.lock"
conf="${HOME}/.config/le-edubar/current_theme/cairo-dock.conf"
conf2="${HOME}/.config/le-edubar/current_theme/_MainDock_-2.conf"
current_pid=$$
v_width=( 800 1024 1024 1366 1280 1280 1600 1650 1920)
v_height=( 600 760 768 768 800 1024 1200 1050 1080)
v_length=${#v_width[@]}
prefix="file:///usr/share/backgrounds/le5-wallpaper"
user=$(whoami|cut -d- -f1)

function get_screen_width () {
    xrandr --current | grep current | cut -d"," -f 2 | cut -d" " -f3 2>/dev/null
}

function get_screen_height () {
    xrandr --current | grep current | cut -d"," -f 2 | cut -d" " -f5 2>/dev/null
}

function replace_cairo_conf () {
    local width=$1
    local height=$2
    [ -z "$width" ] && width=$(get_screen_width)
    [ -z "$height" ] && height=$(get_screen_height)
    if [ -f "$dir/cairo-dock-$width-$height.conf" ]; then
        cp "$dir/cairo-dock-$width-$height.conf" $conf
		cp "$dir/_MainDock_-2.conf" $conf2
    else
	i=0
	less_w=0
	save_i=0
        while [ $i -lt ${v_length} ]
        do
            v_diff_w=$((v_width[i]-$width))
            # If v_diff is a negative 
            if [  $v_diff_w -lt 0 ]; then
                v_diff_w=$((v_diff_w*-1))
            fi
            if [ $i -eq 0 ]; then
                less_w=$v_diff_w
            fi
            if [ $v_diff_w -lt $less_w ]; then
                less_w=$v_diff_w
                save_i=$i
            fi
            ((i++))
        done
        cp "$dir/cairo-dock-${v_width[save_i]}-${v_height[save_i]}.conf" $conf
		cp "$dir/_MainDock_-2.conf" $conf2
    fi
}

function set_default_background(){
    local resolution=$1
    gsettings set org.gnome.desktop.background picture-uri ${prefix}${resolution}.png
    gsettings set org.gnome.desktop.background picture-options 'stretched'
}

# The function verifies if the system is from proinfo project or private machine.
function check_proinfo(){
    if dpkg --get-selections | grep -q le-proinfodata; then
        echo "true" # Return true to proinfo installed
    else
        echo "false"
    fi
}

# The function verifies if the background s diferent from default
function using_default_background(){
    local background=$(gsettings get org.gnome.desktop.background picture-uri)
   
    if [ "$background" == "'${prefix}1920X1080.png'" -o "$background" == "'${prefix}1600X1200.png'" ]; then
        return 0 # Return true to background like default
    else
        return 1 
    fi
}
# The function adjust and set the default background
function adjust_background_default(){
    local compares=$1
    if [ $compares -eq 1 ]; then
        set_default_background "1600X1200"
    else
        set_default_background "1920X1080"
    fi
}

old_pid=$(cat $lock 2>/dev/null)
# Avoid creating multiple instances of this script
if [ -n "$old_pid" ] && kill -0 $old_pid 2> /dev/null; then
    # Reopen le-edubar, just to make sure it is in the right position
    replace_cairo_conf
    pkill le-edubar
    le-edubar -c &
    exit 0
else
    echo $current_pid > $lock
fi

proinfo=$(check_proinfo)

while true
do
    reopen_edubar="false"

    # Get current screen resolution
    width=$(get_screen_width)
    height=$(get_screen_height)
    div=$(echo "scale=1;$width/$height"|bc)
    compare=$(echo "$div < 1.5"|bc)

    # We will force the aluno user to use the default background in the correct
    # aspect ratio. Other users will get the aspect ratio fixed only if they are
    # using the default background.
    if [ "$proinfo" = "true" -a "$user" = "aluno" ] || using_default_background; then
        adjust_background_default "$compare"
    fi

    # Check whether screen resolution has changed
    if [ "$width" != "$width_old" -o "$height" != "$height_old" ]; then
        width_old=$width
        height_old=$height
        reopen_edubar="true"
    fi

    # Check if there is an irregular number of instances of le-edubar
    # running.
    if [ $(pgrep -U $USER le-edubar | wc -l) -ne 1 ]; then
        reopen_edubar="true"
    fi
    if [ "$reopen_edubar" == "true" ]; then
        replace_cairo_conf $width $height
        pkill le-edubar
        le-edubar -c &
    fi
    sleep 5
done
